@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -47,6 +47,7 @@
 #include <QtCore/qrect.h>
 #include <QtCore/qline.h>
 #include <QtCore/qvector.h>
+#include <QtCore/qscopedpointer.h>
 
 QT_BEGIN_HEADER
 
@@ -56,6 +57,7 @@ QT_MODULE(Gui)
 
 class QFont;
 class QPainterPathPrivate;
+struct QPainterPathPrivateDeleter;
 class QPainterPathData;
 class QPainterPathStrokerPrivate;
 class QPolygonF;
@@ -147,6 +149,12 @@ public:
     bool contains(const QRectF &rect) const;
     bool intersects(const QRectF &rect) const;
 
+    void translate(qreal dx, qreal dy);
+    inline void translate(const QPointF &offset);
+
+    QPainterPath translated(qreal dx, qreal dy) const;
+    inline QPainterPath translated(const QPointF &offset) const;
+
     QRectF boundingRect() const;
     QRectF controlPointRect() const;
 
@@ -195,7 +203,7 @@ public:
     QPainterPath &operator-=(const QPainterPath &other);
 
 private:
-    QPainterPathPrivate *d_ptr;
+    QScopedPointer<QPainterPathPrivate, QPainterPathPrivateDeleter> d_ptr;
 
     inline void ensureData() { if (!d_ptr) ensureData_helper(); }
     void ensureData_helper();
@@ -205,13 +213,14 @@ private:
     void computeBoundingRect() const;
     void computeControlPointRect() const;
 
-    QPainterPathData *d_func() const { return reinterpret_cast<QPainterPathData *>(d_ptr); }
+    QPainterPathData *d_func() const { return reinterpret_cast<QPainterPathData *>(d_ptr.data()); }
 
     friend class QPainterPathData;
     friend class QPainterPathStroker;
     friend class QPainterPathStrokerPrivate;
     friend class QMatrix;
     friend class QTransform;
+    friend class QVectorPath;
     friend Q_GUI_EXPORT const QVectorPath &qtVectorPathForPath(const QPainterPath &);
 
 #ifndef QT_NO_DATASTREAM
@@ -229,6 +238,8 @@ public:
     friend class QPainterPathStrokerPrivate;
     friend class QMatrix;
     friend class QTransform;
+    friend class QVectorPath;
+    friend struct QPainterPathPrivateDeleter;
 #ifndef QT_NO_DATASTREAM
     friend Q_GUI_EXPORT QDataStream &operator<<(QDataStream &, const QPainterPath &);
     friend Q_GUI_EXPORT QDataStream &operator>>(QDataStream &, QPainterPath &);
@@ -279,7 +290,7 @@ public:
 private:
     friend class QX11PaintEngine;
 
-    QPainterPathStrokerPrivate *d_ptr;
+    QScopedPointer<QPainterPathStrokerPrivate> d_ptr;
 };
 
 inline void QPainterPath::moveTo(qreal x, qreal y)
@@ -292,9 +303,9 @@ inline void QPainterPath::lineTo(qreal x, qreal y)
     lineTo(QPointF(x, y));
 }
 
-inline void QPainterPath::arcTo(qreal x, qreal y, qreal w, qreal h, qreal startAngle, qreal arcLenght)
+inline void QPainterPath::arcTo(qreal x, qreal y, qreal w, qreal h, qreal startAngle, qreal arcLength)
 {
-    arcTo(QRectF(x, y, w, h), startAngle, arcLenght);
+    arcTo(QRectF(x, y, w, h), startAngle, arcLength);
 }
 
 inline void QPainterPath::arcMoveTo(qreal x, qreal y, qreal w, qreal h, qreal angle)
@@ -365,6 +376,12 @@ inline void QPainterPath::addText(qreal x, qreal y, const QFont &f, const QStrin
     addText(QPointF(x, y), f, text);
 }
 
+inline void QPainterPath::translate(const QPointF &offset)
+{ translate(offset.x(), offset.y()); }
+
+inline QPainterPath QPainterPath::translated(const QPointF &offset) const
+{ return translated(offset.x(), offset.y()); }
+
 inline bool QPainterPath::isEmpty() const
 {
     return !d_ptr || (d_ptr->elements.size() == 1 && d_ptr->elements.first().type == MoveToElement);
