@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -53,7 +53,9 @@ QT_MODULE(ScriptTools)
 class QAction;
 class QScriptEngine;
 class QWidget;
+#ifndef QT_NO_MAINWINDOW
 class QMainWindow;
+#endif
 class QMenu;
 class QToolBar;
 
@@ -92,6 +94,11 @@ public:
         GoToLineAction
     };
 
+    enum DebuggerState {
+        RunningState,
+        SuspendedState
+    };
+
     QScriptEngineDebugger(QObject *parent = 0);
     ~QScriptEngineDebugger();
 
@@ -101,13 +108,17 @@ public:
     bool autoShowStandardWindow() const;
     void setAutoShowStandardWindow(bool autoShow);
 
+#ifndef QT_NO_MAINWINDOW
     QMainWindow *standardWindow() const;
+#endif
     QToolBar *createStandardToolBar(QWidget *parent = 0);
     QMenu *createStandardMenu(QWidget *parent = 0);
 
     QWidget *widget(DebuggerWidget widget) const;
     QAction *action(DebuggerAction action) const;
 
+    DebuggerState state() const;
+
 Q_SIGNALS:
     void evaluationSuspended();
     void evaluationResumed();
