@@ -8,8 +8,8 @@
 /* Machine byte-order */
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
-#define QT_BUILD_KEY "i386 openbsd g++-3.* full-config"
-#define QT_BUILD_KEY_COMPAT "i386 OpenBSD g++-3.* full-config"
+#define QT_BUILD_KEY "i386 openbsd g++-4 full-config"
+#define QT_BUILD_KEY_COMPAT "i386 OpenBSD g++-4 full-config"
 
 #ifdef QT_BOOTSTRAPPED
 #define Q_BYTE_ORDER Q_LITTLE_ENDIAN
@@ -32,12 +32,30 @@
 # define QT_BUILTIN_GIF_READER 1
 #endif
 
+#if defined(QT_NO_ALSA) && defined(QT_ALSA)
+# undef QT_NO_ALSA
+#elif !defined(QT_NO_ALSA) && !defined(QT_ALSA)
+# define QT_NO_ALSA
+#endif
+
 #if defined(QT_NO_CLOCK_MONOTONIC) && defined(QT_CLOCK_MONOTONIC)
 # undef QT_NO_CLOCK_MONOTONIC
 #elif !defined(QT_NO_CLOCK_MONOTONIC) && !defined(QT_CLOCK_MONOTONIC)
 # define QT_NO_CLOCK_MONOTONIC
 #endif
 
+#if defined(QT_NO_DECLARATIVE) && defined(QT_DECLARATIVE)
+# undef QT_NO_DECLARATIVE
+#elif !defined(QT_NO_DECLARATIVE) && !defined(QT_DECLARATIVE)
+# define QT_NO_DECLARATIVE
+#endif
+
+#if defined(QT_NO_EGL) && defined(QT_EGL)
+# undef QT_NO_EGL
+#elif !defined(QT_NO_EGL) && !defined(QT_EGL)
+# define QT_NO_EGL
+#endif
+
 #if defined(QT_NO_ICONV) && defined(QT_ICONV)
 # undef QT_NO_ICONV
 #elif !defined(QT_NO_ICONV) && !defined(QT_ICONV)
@@ -80,18 +98,18 @@
 # define QT_NO_NAS
 #endif
 
+#if defined(QT_NO_OPENVG) && defined(QT_OPENVG)
+# undef QT_NO_OPENVG
+#elif !defined(QT_NO_OPENVG) && !defined(QT_OPENVG)
+# define QT_NO_OPENVG
+#endif
+
 #if defined(QT_NO_SXE) && defined(QT_SXE)
 # undef QT_NO_SXE
 #elif !defined(QT_NO_SXE) && !defined(QT_SXE)
 # define QT_NO_SXE
 #endif
 
-#if defined(QT_NO_WEBKIT) && defined(QT_WEBKIT)
-# undef QT_NO_WEBKIT
-#elif !defined(QT_NO_WEBKIT) && !defined(QT_WEBKIT)
-# define QT_NO_WEBKIT
-#endif
-
 #if defined(QT_NO_ZLIB) && defined(QT_ZLIB)
 # undef QT_NO_ZLIB
 #elif !defined(QT_NO_ZLIB) && !defined(QT_ZLIB)
@@ -122,3 +140,5 @@
 # define QT_USE_MATH_H_FLOATS
 #endif
 
+#define QT_VISIBILITY_AVAILABLE
+
