@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -41,24 +46,32 @@
 #include <QtGui/qcolor.h>
 #include <QtCore/qnamespace.h>
 #include <QtCore/qstring.h> // char*->QString conversion
+#include <QtCore/qsharedpointer.h>
 #include <QtGui/qimage.h>
 #include <QtGui/qtransform.h>
 
 QT_BEGIN_HEADER
 
+#if defined(Q_OS_SYMBIAN)
+class CFbsBitmap;
+class RSgImage;
+#endif
+
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Gui)
 
 class QImageWriter;
 class QColor;
 class QVariant;
 class QX11Info;
-
-struct QPixmapData;
+class QPixmapData;
 
 class Q_GUI_EXPORT QPixmap : public QPaintDevice
 {
 public:
     QPixmap();
+    explicit QPixmap(QPixmapData *data);
     QPixmap(int w, int h);
     QPixmap(const QSize &);
     QPixmap(const QString& fileName, const char *format = 0, Qt::ImageConversionFlags flags = Qt::AutoColor);
@@ -71,11 +84,11 @@ public:
     QPixmap &operator=(const QPixmap &);
     operator QVariant() const;
 
-    bool isNull() const;
+    bool isNull() const; // ### Qt 5: make inline
     int devType() const;
 
-    int width() const;
-    int height() const;
+    int width() const; // ### Qt 5: make inline
+    int height() const; // ### Qt 5: make inline
     QSize size() const;
     QRect rect() const;
     int depth() const;
@@ -131,11 +144,15 @@ public:
 #if defined(Q_WS_WIN)
     enum HBitmapFormat {
         NoAlpha,
-        PremultipliedAlpha
+        PremultipliedAlpha,
+        Alpha
     };
 
     HBITMAP toWinHBITMAP(HBitmapFormat format = NoAlpha) const;
+    HICON toWinHICON() const;
+
     static QPixmap fromWinHBITMAP(HBITMAP hbitmap, HBitmapFormat format = NoAlpha);
+    static QPixmap fromWinHICON(HICON hicon);
 #endif
 
 #if defined(Q_WS_MAC)
@@ -143,27 +160,43 @@ public:
     static QPixmap fromMacCGImageRef(CGImageRef image);
 #endif
 
+#if defined(Q_OS_SYMBIAN)
+    CFbsBitmap *toSymbianCFbsBitmap() const;
+    static QPixmap fromSymbianCFbsBitmap(CFbsBitmap *bitmap);
+    RSgImage* toSymbianRSgImage() const;
+    static QPixmap fromSymbianRSgImage(RSgImage *sgImage);
+#endif
+
     inline QPixmap copy(int x, int y, int width, int height) const;
     QPixmap copy(const QRect &rect = QRect()) const;
 
+    inline void scroll(int dx, int dy, int x, int y, int width, int height, QRegion *exposed = 0);
+    void scroll(int dx, int dy, const QRect &rect, QRegion *exposed = 0);
+
     int serialNumber() const;
     qint64 cacheKey() const;
 
     bool isDetached() const;
     void detach();
 
-    inline bool isQBitmap() const { return depth() == 1; }
+    bool isQBitmap() const;
 
 #if defined(Q_WS_QWS)
     const uchar *qwsBits() const;
     int qwsBytesPerLine() const;
     QRgb *clut() const;
-    int numCols() const;
+#ifdef QT_DEPRECATED
+    QT_DEPRECATED int numCols() const;
+#endif
+    int colorCount() const;
 #elif defined(Q_WS_MAC)
     Qt::HANDLE macQDHandle() const;
     Qt::HANDLE macQDAlphaHandle() const;
     Qt::HANDLE macCGHandle() const;
 #elif defined(Q_WS_X11)
+    enum ShareMode { ImplicitlyShared, ExplicitlyShared };
+
+    static QPixmap fromX11Pixmap(Qt::HANDLE pixmap, ShareMode mode = ImplicitlyShared);
     static int x11SetDefaultScreen(int screen);
     void x11SetScreen(int screen);
     const QX11Info &x11Info() const;
@@ -204,26 +237,33 @@ public:
 #endif
 
 private:
-    QPixmapData *data;
+    QExplicitlySharedDataPointer<QPixmapData> data;
 
     bool doImageIO(QImageWriter *io, int quality) const;
-    enum Type { PixmapType, BitmapType };
+
+    // ### Qt5: remove the following three lines
+    enum Type { PixmapType, BitmapType }; // must match QPixmapData::PixelType
     QPixmap(const QSize &s, Type);
     void init(int, int, Type = PixmapType);
+
+    QPixmap(const QSize &s, int type);
+    void init(int, int, int);
     void deref();
 #if defined(Q_WS_WIN)
     void initAlphaPixmap(uchar *bytes, int length, struct tagBITMAPINFO *bmi);
 #endif
     Q_DUMMY_COMPARISON_OPERATOR(QPixmap)
 #ifdef Q_WS_MAC
-    friend CGContextRef qt_mac_cg_context(const QPaintDevice *);
-    friend CGImageRef qt_mac_create_imagemask(const QPixmap &, const QRectF &rect);
-    friend IconRef qt_mac_create_iconref(const QPixmap &);
-    friend QPixmap qt_mac_unmultiplyPixmapAlpha(const QPixmap &);
-    friend quint32 *qt_mac_pixmap_get_base(const QPixmap *);
-    friend int qt_mac_pixmap_get_bytes_per_line(const QPixmap *);
+    friend CGContextRef qt_mac_cg_context(const QPaintDevice*);
+    friend CGImageRef qt_mac_create_imagemask(const QPixmap&, const QRectF&);
+    friend IconRef qt_mac_create_iconref(const QPixmap&);
+    friend quint32 *qt_mac_pixmap_get_base(const QPixmap*);
+    friend int qt_mac_pixmap_get_bytes_per_line(const QPixmap*);
 #endif
-    friend struct QPixmapData;
+    friend class QPixmapData;
+    friend class QX11PixmapData;
+    friend class QMacPixmapData;
+    friend class QS60PixmapData;
     friend class QBitmap;
     friend class QPaintDevice;
     friend class QPainter;
@@ -233,16 +273,17 @@ private:
     friend class QWidgetPrivate;
     friend class QRasterPaintEngine;
     friend class QRasterBuffer;
-    friend class QDirect3DPaintEngine;
-    friend class QDirect3DPaintEnginePrivate;
-    friend class QDetachedPixmap;
+    friend class QPixmapCacheEntry;
 #if !defined(QT_NO_DATASTREAM)
     friend Q_GUI_EXPORT QDataStream &operator>>(QDataStream &, QPixmap &);
 #endif
     friend Q_GUI_EXPORT qint64 qt_pixmap_id(const QPixmap &pixmap);
 
 public:
-    typedef QPixmapData * DataPtr;
+    QPixmapData* pixmapData() const;
+
+public:
+    typedef QExplicitlySharedDataPointer<QPixmapData> DataPtr;
     inline DataPtr &data_ptr() { return data; }
 };
 
@@ -253,6 +294,11 @@ inline QPixmap QPixmap::copy(int ax, int ay, int awidth, int aheight) const
     return copy(QRect(ax, ay, awidth, aheight));
 }
 
+inline void QPixmap::scroll(int dx, int dy, int ax, int ay, int awidth, int aheight, QRegion *exposed)
+{
+    scroll(dx, dy, QRect(ax, ay, awidth, aheight), exposed);
+}
+
 inline bool QPixmap::loadFromData(const QByteArray &buf, const char *format,
                                   Qt::ImageConversionFlags flags)
 {
@@ -276,6 +322,8 @@ QT3_SUPPORT Q_GUI_EXPORT void copyBlt(QPixmap *dst, int dx, int dy, const QPixma
                                     int sx=0, int sy=0, int sw=-1, int sh=-1);
 #endif // QT3_SUPPORT
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QPIXMAP_H
